{
    Respond, the fax number form daemon
    Copyright (C) 2000 Horst F <horstf@gmx.de>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
}
unit Header;

interface

uses
  SysUtils, WinTypes, WinProcs, Classes, CommonDataAccess;

type
  { Enter 'Delay': off, as checkbox or as edit field }
  TDelayed = (dOff, dCheck, dEdit);

  { Enum for labels (CKeys and CLabelValues) }
  KeyIndexes = (
    KIQueryFrom, KIWaiting, KIOptions,
    KIClose, KIAbout, KIPhoneBook,
    KIReceiver, KIFaxNums, KIRecvName,
    KISender, KIUser, KISendName, KIAlias,
    KIOK, KICancel, KIPort, KILabels, KILoadNetAPI, KISaveHist,
    KIHistory, KIQuerySave, KIMore, KILookupHost, KIMoreEnabled,
    KIMaxHistory, KIErrReadOnlyEntry, KIErrOutOfMemory,
    KIDelayed, KIdOff, KIdCheck, KIdEdit
  );

  TChar = array[0..255]of Char;

const
  DefaultPort = 5555;

  KIFirst = KIQueryFrom;       { First element of KeyIndexes }
  KILast = KIdEdit;            { Last element of KeyIndexes  }

  CProgName = 'Respond';       { Program name }
  CProgVersion = '1.6.0beta';{ Version      }

  { INI file names }
  RespondIniFileName = CProgName + '.ini';
  WinIniFileName = 'WIN.INI';
  { Respond.ini file }
  RespondIniFile: String = '';
  { Win.ini file }
  WinIniFile: String = 'WIN.INI';
  { file for options }
  OptionsFile: String = '';
  { file for labels, regularly Win.ini }
  LabelFile: String = '';
  { file for private phonebook entries, regularly Respond.ini }
  PrivatePhonebookFile: String = '';
  { file for history entries, regularly Respond.ini }
  HistoryFile: String = '';
  { file for common (shared) read only phonebook entries}
  CommonPhonebookFile: String = '';
  { file with port list for use on terminal server machines }
  ServerPortsFile: String = '';


  { Menuitems for system menu or trayicon popup menu }
{$IFDEF WIN32}
  CloseMenuItemString : array[0..255]of Char = '';
  CloseMenuItem : PChar = @CloseMenuItemString;
{$ENDIF}
  AboutMenuItemString : array[0..255]of Char = '';
  AboutMenuItem : PChar = @AboutMenuItemString;
  PBookMenuItemString : array[0..255]of Char = '';
  PBookMenuItem : PChar = @PBookMenuItemString;

{$IFDEF WIN32}
  { Registry entry for user name }
  UserNameKey: PChar = 'Network\Logon';
  UserNameValue: PChar = 'username';
{$ENDIF}

  { WIN.INI entries: }
  { Section names }
  OptionsSection  = CProgName;
  LabelsSection  = CProgName+'-Labels';
  { Key names }
  PortValueKey : PChar = 'Port';
  DelayedKey : PChar = 'Delayed';
  LoadNetAPIKey: PChar = 'LoadNetAPI';
  SaveHistoryKey: PChar = 'SaveHistory';
  MaxHistKey: PChar = 'MaxHistory';
  QueryReceiverNameKey: PChar = 'QueryReceiverName';
  QueryUserKey: PChar = 'QueryUser';
  QuerySenderNameKey: PChar = 'QuerySenderName';
  RememberMoreKey: PChar = 'RememberMore';
  LookupHostKey: PChar = 'LookupHostName';
  MoreKey: PChar = 'MoreEnabled';

  { Respond.ini entries: }
  AliasSection = 'Aliases';
  PrivatePhonebookSection = AliasSection;
  CommonPhonebookSection = 'CommonAliases';
  HistorySection  = 'History';

  KMaxHistory = 10;
  KGetMem = 2048;

  KeyCount = Ord(KILast)-Ord(KIFirst)+1;       { Label key count }

  { CKeys covers the label keys from WIN.INI }
  CKeys : array[KeyIndexes]of String = (
    'QueryFrom',
    'Waiting',
    'Options',
    'Close',
    'About',
    'PhoneBook',
    'Receiver',
    'Faxnumbers',
    'ReceiverName',
    'Sender',
    'User',
    'SenderName',
    'Alias',
    'OK',
    'Cancel',
    'Port',
    'Labels',
    'LoadNetAPI',
    'SaveHistory',
    'History',
    'QuerySave',
    'More',
    'LookupHostName',
    'MoreEnabled',
    'MaxHistory',
    'ErrReadOnlyEntry',
    'ErrOutOfMemory',
    'Delayed',
    'DelayedOff',
    'DelayedCheck',
    'DelayedEdit'
  );

  { CLabelValues covers the label names from WIN.INI }
  CLabelValues : array[KeyIndexes]of String = (
    'Query from',
    'Waiting',
    '&Options',
    '&Close',
    '&About',
    '&Phonebook',
    'Receiver',
    '&Fax-Number(s)',
    '&Name',
    'Sender',
    '&User',
    'N&ame',
    'A&lias',
    '&OK',
    '&Cancel',
    '&Port',
    '&Labels',
    'Load N&ETAPI.DLL',
    'Save &History',
    'History',
    'Save changed values?',
    'Mo&re',
    '&Lookup host name',
    'Additional input &field',
    '&Max. history entries',
    'This entry is read only!',
    'Not enough memory!',
    '&Delayed Send',
    'Off',
    'Checkbox',
    'Editfield'
  );

  SeparatorChars : Set of Char = [' ',','];

procedure ProcessOptions;
function UnShortCut( const s: String ): String;
function GetLabelStr(const KI: KeyIndexes): String;
procedure GetLabelPChar(const KI: KeyIndexes; p: PChar; l: Integer);

implementation

{ Process commandline options }
procedure ProcessOptions;
type
  // Enumeration of existing options, last comment part is the default location
  OptionType = (oLabels,      { Labels, win.ini }
                oOptions,     { Options, win.ini }
                oAliases,     { Private phonebook, respond.ini }
                oHistory,     { History, respond.ini }
                oPrivate,     { depricated, options and labels, win.ini }
                oCommonPB,    { Common read only phonebook, none }
                oOldLabels,   { depricated, labels, win.ini }
                oPorts);      { Port list for terminal server }
const
  OptionCount = 8;
  { Array of existing options }
  OptionChars: array [1..OptionCount] of Char =
      ('b', 'o', 'a', 'h', 'p', 'c', 'l', 's');
  { Array of enumerations sets of existing options }
  OptionSets: array [1..OptionCount] of
      set of OptionType = ([oLabels], [oOptions], [oAliases], [oHistory],
          [oPrivate], [oCommonPB], [oOldLabels], [oPorts]);
var
  o, fn: String;
  i, m, n: Integer;
  os: set of OptionType;
  p : array[0..255]of Char;
  loption, poption : Boolean;
begin
  // Workaround for own read funktion for phonebook file;
  // we need the whole filename
  m := 255 - Length(RespondIniFileName) - 1;
  i := GetWindowsDirectory(@p, m);
  if (i > 0) and (i <= m) then begin
    if p[i] <> '\' then StrCat(p, '\');
    RespondIniFile := StrPas(@p) + RespondIniFileName;
  end else begin
    RespondIniFile := RespondIniFileName;
  end;
  loption := false;
  poption := false;
  for i := 1 to ParamCount do begin
    o := ParamStr(i);
    { If it is a switch }
    if (o[1] = '-') or (o[1] = '/') then begin
      { Delete switch char }
      Delete(o,1,1);
      { Clear options set }
      os := [];
      { Search options string for every existing options char }
      for n := 1 to OptionCount do begin
        m := Pos(OptionChars[n], o);
        { if found }
        if m > 0 then begin
          { add it to options set }
          os := os + OptionSets[n];
          { old style options processing: }
          { Put labels in Respond.ini }
          if o[m] = 'l' then loption := true;
          { Put labels and options in Respond.ini }
          if o[m] = 'p' then poption := true;
          { delete found char from options string }
          delete(o, m, 1);
        end;
      end;
    end else begin
      { Make sure that dir strings ends with \ }
      if o[Length(o)] <> '\' then AppendStr(o, '\');
      { Build filename }
      fn := o+CProgName+'.ini';
      { Set filename for every option in options set
       (i.e. options found in option string) }
      if oLabels in os then begin
        LabelFile := fn;
        loption := false;
        poption := false;
      end;
      if oOptions in os then begin
        OptionsFile := fn;
        poption := false;
      end;
      if oAliases in os then begin
        PrivatePhonebookFile := fn;
      end;
      if oHistory in os then begin
        HistoryFile := fn;
      end;
      if oCommonPB in os then begin
        CommonPhonebookFile := fn;
      end;
      if oPorts in os then begin
        ServerPortsFile := fn;
      end;
      { Old style option processing }
      if (oPrivate in os) or
         (oOldLabels in os) then begin
        RespondIniFile := fn;
      end;
      { Clear optios set; needed in case of invalid commandline }
      os := [];
    end;
  end;
  { Old option style handling }
  if loption then begin
    LabelFile := RespondIniFile;
  end;
  if poption then begin
    OptionsFile := RespondIniFile;
    LabelFile := RespondIniFile;
  end;
  if length(HistoryFile) = 0 then HistoryFile := RespondIniFile;
  if length(LabelFile) = 0 then LabelFile := WinIniFile;
  if length(OptionsFile) = 0 then OptionsFile := WinIniFile;
  if length(PrivatePhonebookFile) = 0 then
      PrivatePhonebookFile := RespondIniFile;
end;

function UnShortCut( const s: String ): String;
{ Remove Shortcut-'&' from String }
var
  i: Integer;
begin
  result := s;
  i := Pos( '&', result );
  if i > 0 then Delete( result, i, 1 );
end;

{ Read label from INI file as String }
function GetLabelStr(const KI: KeyIndexes): String;
begin
  Result := TCommonData.ReadString(LabelsSection, CKeys[KI], CLabelValues[KI]);
end;

{ Read label from INI file as PChar }
procedure GetLabelPChar(const KI: KeyIndexes; p: PChar; l: Integer);
var
  s : String;
begin
  s := GetLabelStr(KI);
  StrLCopy(p, PChar(s), l);
end;

end.
