{
    Respond, the fax number form daemon
    Copyright (C) 2000 Horst F <horstf@gmx.de>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
}
unit Phbook;

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, StdCtrls, Buttons, Grids, Header, IniFile, Observer,
  CommonDataAccess, ObservedStringList;

const
  MaxEditEntries : Integer = 10000;

type
  TPhBookForm = class(TForm)
    OKBtn: TBitBtn;
    AliasList: TListBox;
    PlusBtn: TButton;
    MinusBtn: TButton;
    Alias: TEdit;
    FaxNum: TEdit;
    Empfaenger: TEdit;
    EmpfaengerLabel: TLabel;
    FaxNumLabel: TLabel;
    AliasLabel: TLabel;
    AliasListLabel: TLabel;
    procedure FormCreate(Sender: TObject);
    procedure AliasListClick(Sender: TObject);
    procedure PlusBtnClick(Sender: TObject);
    procedure MinusBtnClick(Sender: TObject);
    procedure InputChange(Sender: TObject);
    procedure AliasListExit(Sender: TObject);
    procedure AliasListEnter(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
  private
    { Private-Deklarationen }
    procedure Reload;
  public
    { Public-Deklarationen }
    procedure Preset(AnAlias, AFaxNum, AReceiver: String);
  end;

implementation

{$R *.DFM}

procedure TPhBookForm.FormCreate(Sender: TObject);
begin
  Caption := CProgName+' '+UnShortCut(StrPas(PBookMenuItem));
  OKBtn.Caption := GetLabelStr(KIClose);
  AliasLabel.Caption := GetLabelStr(KIAlias);
  AliasListLabel.Caption := GetLabelStr(KIAlias);
  FaxNumLabel.Caption := GetLabelStr(KIFaxNums);
  EmpfaengerLabel.Caption := GetLabelStr(KIRecvName);
  MinusBtn.Enabled := False;
end;

procedure TPhBookForm.FormShow(Sender: TObject);
begin
  reload;
end;

procedure TPhBookForm.Reload;
begin
  AliasList.Clear;
  TCommonData.ReadTableKeys(PrivatePhonebookSection, AliasList.Items);
end;

procedure TPhBookForm.Preset(AnAlias, AFaxNum, AReceiver: String);
begin
  Alias.Text := AnAlias;
  FaxNum.Text := AFaxNum;
  Empfaenger.Text := AReceiver;
  PlusBtn.Enabled := False;
  MinusBtn.Enabled := False;
  OkBtn.Default := True;
end;

procedure TPhBookForm.AliasListClick(Sender: TObject);
{ Replacement for the OnChange list event }
var
  key : String;
  sl : TObservedStringList;
begin
  with AliasList do begin
    if ItemIndex >= 0 then begin
      sl := nil;
      key := Items.Strings[ItemIndex];
      try
        sl := TObservedStringList.Create();
        sl.Sorted := false;
        TCommonData.ReadFields(PrivatePhonebookSection, key, sl);
        if sl.Count > 0 then begin
          Alias.Text := key;
          FaxNum.Text := sl.Strings[0];
          if sl.Count > 1 then Empfaenger.Text := sl.Strings[1]
              else Empfaenger.Text := '';
          PlusBtn.Default := False;
          OKBtn.Default := False;
          MinusBtn.Enabled := True;
          MinusBtn.Default := True;
        end;
      except
        on EOutOfMemory do begin
          MessageDlg(GetLabelStr(KIErrOutOfMemory), mtError, [mbOK], 0);
        end;
      end;
      sl.Free;
    end;
  end;
end;

procedure TPhBookForm.PlusBtnClick(Sender: TObject);
{ Add an alias }
var
  sl: TObservedStringList;
begin
  if ( Alias.Text <> '' ) and ( FaxNum.Text <> '' ) then begin
    sl := nil;
    try
      sl := TObservedStringList.Create();
      sl.Add(FaxNum.Text);
      sl.Add(Empfaenger.Text);
      TCommonData.WriteFields(PrivatePhonebookSection, Alias.Text, sl);
    except
      on EOutOfMemory do begin
        MessageDlg(GetLabelStr(KIErrOutOfMemory), mtError, [mbOK], 0);
      end;
    end;
    sl.Free;
    reload;
  end;
end;

procedure TPhBookForm.MinusBtnClick(Sender: TObject);
{ Remove an alias }
var
  key : String;
  sl : TObservedStringList;
begin
  with AliasList do begin
    if ItemIndex >= 0 then begin
      sl := nil;
      key := Items.Strings[ItemIndex];
      try
        sl := TObservedStringList.Create();
        TCommonData.ReadFields(PrivatePhonebookSection, key, sl);
        if sl.Count > 0 then begin
          Alias.Text := key;
          FaxNum.Text := sl.Strings[1];
          if sl.Count > 1 then Empfaenger.Text := sl.Strings[2]
              else Empfaenger.Text := '';
          PlusBtn.Default := False;
          OKBtn.Default := False;
          MinusBtn.Default := True;
        end;
        TCommonData.DeleteKey(PrivatePhonebookSection, key);
      except
        on EOutOfMemory do;
      end;
      sl.Free;
      reload;
    end;
  end;
end;

procedure TPhBookForm.InputChange(Sender: TObject);
begin
  if not AliasList.Focused then begin
    PlusBtn.Enabled := Alias.Text <> '';
    PlusBtn.Default := PlusBtn.Enabled;
    OKBtn.Default := not PlusBtn.Default;
  end;
end;

procedure TPhBookForm.AliasListExit(Sender: TObject);
begin
  if MinusBtn.Default = True then begin
    MinusBtn.Default := False;
    if Alias.Text <> '' then PlusBtn.Default := True
    else OKBtn.Default := True;
  end;
end;

procedure TPhBookForm.AliasListEnter(Sender: TObject);
begin
  if AliasList.ItemIndex >= 0 then begin
    PlusBtn.Default := False;
    OKBtn.Default := False;
    MinusBtn.Default := True;
  end;
end;

procedure TPhBookForm.FormClose(Sender: TObject; var Action: TCloseAction);
begin
  TCommonData.Flush(PrivatePhonebookSection);
end;

end.
