{
    Respond, the fax number form daemon
    Copyright (C) 2000 Horst F <horstf@gmx.de>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
}
unit TableDescription;

interface

  uses
    classes, DatabaseDescription, Observer;

  type
    {
      Describes, which fields and separator a table has.
      The fields object will be automatically freed when freeing the
      TTableDescription object, the associated TDatabaseDescription object
      not!!!
    }
    TTableDescription = class(TObject)
    private
      oName: String;
      oFields : TStrings;
      oSeparator : String;
      oDatabaseDescription : TDatabaseDescription;
    public
      constructor Create(const name: String;
          const dbdescription: TDatabaseDescription);
      destructor Destroy; override;
      property name: String read oName;
      property Fields: TStrings read oFields write oFields;
      property Separator: String read oSeparator write oSeparator;
      property DatabaseDescription: TDatabaseDescription
          read oDatabaseDescription;
    end;

implementation

  {
    Creates and fills the object.

    @param name (physical) table name
    @param dbdescription TDatabaseDescription object
  }
  constructor TTableDescription.Create(const name: String;
      const dbdescription: TDatabaseDescription);
  begin
    oFields := nil;
    inherited Create;
    oName := name;
    oSeparator := ': ';
    oDatabaseDescription := dbdescription;
    ObjectObserver.Observe(self);
  end;

  {
    Destroys the object.
  }
  destructor TTableDescription.Destroy;
  begin
    oFields.Free;
    ObjectObserver.Forget(self);
    inherited Destroy;
  end;

end.
